@@ -6,9 +6,10 @@ import subprocess
 import sys
 from dataclasses import dataclass
 from fractions import Fraction
-from platform import machine, system
+from platform import system
 from re import search
 from subprocess import PIPE, Popen
+from typing import Any
 
 from auto_editor.utils.func import get_stdout
 from auto_editor.utils.log import Log
@@ -25,7 +26,7 @@ class FFmpeg:
         ff_location: str | None = None,
         my_ffmpeg: bool = False,
         debug: bool = False,
-    ) -> None:
+    ):
         def _set_ff_path(ff_location: str | None, my_ffmpeg: bool) -> str:
             if ff_location is not None:
                 return ff_location
@@ -47,8 +48,6 @@ class FFmpeg:
             self.version = _version.split(" ")[0]
         except FileNotFoundError:
             if system() == "Darwin":
-                if machine() == "arm64":
-                    Log().error("No ffmpeg found, download via homebrew.")
                 Log().error(
                     "No ffmpeg found, download via homebrew or install ae-ffmpeg."
                 )
@@ -115,7 +114,9 @@ class FFmpeg:
         elif show_out and not self.debug:
             print(f"stderr: {output}")
 
-    def Popen(self, cmd: list[str], stdin=None, stdout=PIPE, stderr=None) -> Popen:
+    def Popen(
+        self, cmd: list[str], stdin: Any = None, stdout: Any = PIPE, stderr: Any = None
+    ) -> Popen:
         cmd = [self.path] + cmd
         self.print_cmd(cmd)
         return Popen(cmd, stdin=stdin, stdout=stdout, stderr=stderr)
@@ -178,7 +179,7 @@ class FileInfo:
         "videos",
         "audios",
         "subtitles",
-        "index",
+        "label",
     )
 
     def get_res(self) -> tuple[int, int]:
@@ -196,8 +197,8 @@ class FileInfo:
             return self.audios[0].samplerate
         return 48000
 
-    def __init__(self, index: int, path: str, ffmpeg: FFmpeg, log: Log):
-        self.index = index
+    def __init__(self, path: str, ffmpeg: FFmpeg, log: Log, label: str = ""):
+        self.label = label
         self.path = path
         self.abspath = os.path.abspath(path)
         self.basename = os.path.basename(path)
@@ -234,9 +235,9 @@ class FileInfo:
                 ]
             )
         except FileNotFoundError:
-            log.error(f"Could not find: {ffprobe}")
+            log.nofile(ffprobe)
 
-        def get_attr(name: str, dic: dict, default=-1) -> str:
+        def get_attr(name: str, dic: dict[Any, Any], default: Any = -1) -> str:
             if name in dic:
                 if isinstance(dic[name], str):
                     return dic[name]
