@@ -20,6 +20,8 @@ def make_new_audio(
     output = []
     samples = {}
 
+    af_tick = 0
+
     if len(timeline.a) == 0 or len(timeline.a[0]) == 0:
         log.error("Trying to render empty audio timeline")
 
@@ -33,7 +35,7 @@ def make_new_audio(
         for c, clip in enumerate(layer):
             if f"{clip.src}-{clip.stream}" not in samples:
                 audio_path = ensure.audio(
-                    timeline.inputs[clip.src].path, clip.src, clip.stream
+                    timeline.sources[clip.src].path, clip.src, clip.stream
                 )
                 samples[f"{clip.src}-{clip.stream}"] = read(audio_path)[1]
 
@@ -65,35 +67,40 @@ def make_new_audio(
             if samp_end > len(samp_list):
                 samp_end = len(samp_list)
 
-            if clip.speed == 1:
-                clip_arr = samp_list[samp_start:samp_end]
-            else:
-                tsm = os.path.join(temp, "tsm.wav")
-                tsm_out = os.path.join(temp, "tsm_out.wav")
-
-                write(tsm, sr, samp_list[samp_start:samp_end])
-
-                cmd = ["-i", tsm, "-af"]
+            filters: list[str] = []
 
+            if clip.speed != 1:
                 if clip.speed > 10_000:
-                    atempo = ",".join([f"atempo={clip.speed}^.33333"] * 3)
+                    filters.extend([f"atempo={clip.speed}^.33333"] * 3)
                 elif clip.speed > 100:
-                    atempo = f"atempo=sqrt({clip.speed}),atempo=sqrt({clip.speed})"
+                    filters.extend(
+                        [f"atempo=sqrt({clip.speed})", f"atempo=sqrt({clip.speed})"]
+                    )
                 elif clip.speed >= 0.5:
-                    atempo = f"atempo={clip.speed}"
+                    filters.append(f"atempo={clip.speed}")
                 else:
                     start = 0.5
-                    m = []
                     while start * 0.5 > clip.speed:
                         start *= 0.5
-                        m.append("atempo=0.5")
-                    m.append(f"atempo={clip.speed / start}")
-                    atempo = ",".join(m)
+                        filters.append("atempo=0.5")
+                    filters.append(f"atempo={clip.speed / start}")
 
-                cmd.extend([atempo, tsm_out])
-                ffmpeg.run(cmd)
+            if clip.volume != 1:
+                filters.append(f"volume={clip.volume}")
 
-                clip_arr = read(tsm_out)[1]
+            if not filters:
+                clip_arr = samp_list[samp_start:samp_end]
+            else:
+                af = os.path.join(temp, f"af{af_tick}.wav")
+                af_out = os.path.join(temp, f"af{af_tick}_out.wav")
+
+                # Windows can't replace a file that's already in use, so we have to
+                # cycle through file names.
+                af_tick = (af_tick + 1) % 3
+
+                write(af, sr, samp_list[samp_start:samp_end])
+                ffmpeg.run(["-i", af, "-af", ",".join(filters), af_out])
+                clip_arr = read(af_out)[1]
 
             # Mix numpy arrays
             start = clip.start * sr // tb
