@@ -4,13 +4,13 @@ import os.path
 from dataclasses import dataclass
 from math import ceil
 from subprocess import DEVNULL, PIPE
+from typing import Any
 
 import av
 from PIL import Image, ImageOps
 
-from auto_editor.ffwrapper import FFmpeg
-from auto_editor.make_layers import Visual
-from auto_editor.objects import VideoObj
+from auto_editor.ffwrapper import FFmpeg, FileInfo
+from auto_editor.objs.tl import TlVideo, Visual
 from auto_editor.output import video_quality
 from auto_editor.render.image import make_caches, render_image
 from auto_editor.timeline import Timeline
@@ -26,7 +26,7 @@ av.logging.set_level(av.logging.PANIC)
 @dataclass
 class VideoFrame:
     index: int
-    src: int
+    src: str
 
 
 # From: github.com/PyAV-Org/PyAV/blob/main/av/video/frame.pyx
@@ -63,22 +63,32 @@ def render_av(
     log: Log,
 ) -> tuple[str, bool]:
 
-    inp = timeline.inp
-    cns = [av.open(inp.path, "r") for inp in timeline.inputs]
+    if not timeline.sources:
+        if "0" in timeline.sources:
+            src: FileInfo | None = timeline.sources["0"]
+        else:
+            src = next(iter(timeline.sources.items()))[1]
+    else:
+        src = None
 
-    font_cache, img_cache = make_caches(timeline.v, log)
+    font_cache, img_cache = make_caches(timeline.v, timeline.sources, log)
+
+    cns: dict[str, Any] = {}
+    decoders: dict[str, Any] = {}
+    seek_cost: dict[str, int] = {}
+    tous: dict[str, int] = {}
 
     target_pix_fmt = "yuv420p"  # Reasonable default
-    decoders = []
-    tous = []
-    seek_cost = []
-    for c, cn in enumerate(cns):
-        if len(cn.streams.video) == 0:
-            decoders.append(None)
-            tous.append(0)
-            seek_cost.append(0)
+
+    for key, src in timeline.sources.items():
+        cns[key] = av.open(src.path)
+
+        if len(cns[key].streams.video) == 0:
+            decoders[key] = None
+            tous[key] = 0
+            seek_cost[key] = 0
         else:
-            stream = cn.streams.video[0]
+            stream = cns[key].streams.video[0]
             stream.thread_type = "AUTO"
 
             if args.no_seek or stream.average_rate is None:
@@ -89,11 +99,11 @@ def render_av(
                 sc_val = int(stream.average_rate * 5)
                 tou = int(stream.time_base.denominator / stream.average_rate)
 
-            seek_cost.append(sc_val)
-            tous.append(tou)
-            decoders.append(cn.decode(stream))
+            seek_cost[key] = sc_val
+            tous[key] = tou
+            decoders[key] = cns[key].decode(stream)
 
-            if c == 0:
+            if key == "0":
                 target_pix_fmt = stream.pix_fmt
 
     log.debug(f"Tous: {tous}")
@@ -139,11 +149,11 @@ def render_av(
     if apply_video_later:
         cmd.extend(["-c:v", "mpeg4", "-qscale:v", "1"])
     else:
-        cmd = video_quality(cmd, args, inp, ctr)
+        cmd = video_quality(cmd, args, ctr)
 
     # Setting SAR requires re-encoding so we do it here.
-    if timeline.inputs and timeline.inputs[0].videos:
-        if (sar := timeline.inputs[0].videos[0].sar) is not None:
+    if src is not None and src.videos:
+        if (sar := src.videos[0].sar) is not None:
             cmd.extend(["-vf", f"setsar={sar.replace(':', '/')}"])
 
     cmd.append(spedup)
@@ -170,7 +180,7 @@ def render_av(
             obj_list: list[VideoFrame | Visual] = []
             for layer in timeline.v:
                 for lobj in layer:
-                    if isinstance(lobj, VideoObj):
+                    if isinstance(lobj, TlVideo):
                         if index >= lobj.start and index < lobj.start + ceil(
                             lobj.dur / lobj.speed
                         ):
@@ -192,6 +202,7 @@ def render_av(
                         log.debug(f"Seek: {frame_index} -> 0")
                         cns[obj.src].seek(0)
                         try:
+                            assert decoders[obj.src] is not None
                             frame = next(decoders[obj.src])
                             frame_index = round(frame.time * timeline.timebase)
                         except StopIteration:
